# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quote/quote.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from quote import quote_enum_pb2 as quote_dot_quote__enum__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='quote/quote.proto',
  package='quote',
  syntax='proto3',
  serialized_options=_b('\242\002\003QUT'),
  serialized_pb=_b('\n\x11quote/quote.proto\x12\x05quote\x1a\x16quote/quote_enum.proto\"\'\n\x06\x42SNode\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0e\n\x06volume\x18\x02 \x01(\x05\"\xa0\x05\n\x08TickData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x0c\n\x04time\x18\x04 \x01(\t\x12\x13\n\x0bmillisecond\x18\x05 \x01(\x05\x12\x12\n\nlast_price\x18\x06 \x01(\x01\x12\x0e\n\x06volume\x18\x07 \x01(\x01\x12\x15\n\ropen_interest\x18\x08 \x01(\x01\x12\x15\n\rhighest_price\x18\t \x01(\x01\x12\x14\n\x0clowest_price\x18\n \x01(\x01\x12\x19\n\x11upper_limit_price\x18\x0b \x01(\x01\x12\x19\n\x11lower_limit_price\x18\x0c \x01(\x01\x12\x1c\n\x14pre_settlement_price\x18\r \x01(\x01\x12\x15\n\raverage_price\x18\x0e \x01(\x01\x12\x1a\n\x03\x62id\x18\x0f \x03(\x0b\x32\r.quote.BSNode\x12\x1a\n\x03\x61sk\x18\x10 \x03(\x0b\x32\r.quote.BSNode\x12\x12\n\nopen_price\x18\x11 \x01(\x01\x12\x17\n\x0fpre_close_price\x18\x12 \x01(\x01\x12\x10\n\x08turnover\x18\x13 \x01(\x01\x12\x32\n\x0finstrument_type\x18\x14 \x01(\x0e\x32\x19.quote.tag.InstrumentType\x12\x19\n\x11pre_open_interest\x18\x15 \x01(\x01\x12\x14\n\x0ctrade_number\x18\x16 \x01(\x05\x12\x13\n\x0blast_volume\x18\x17 \x01(\x05\x12\x1b\n\x13up_down_in_five_min\x18\x18 \x01(\x01\x12\x17\n\x0fsuspension_sign\x18\x19 \x01(\t\x12\x11\n\ttimestamp\x18\x1a \x01(\x05\x12\x13\n\x0bmarket_code\x18\x1b \x01(\t\x12\x15\n\rlast_turnover\x18\x1c \x01(\x01\"\x88\x02\n\x10TransactionsData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\x13\n\x0bmillisecond\x18\x04 \x01(\x05\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x05\x12!\n\x04side\x18\x07 \x01(\x0e\x32\x13.quote.tag.SideType\x12\x17\n\x0fsell_entrust_no\x18\x08 \x01(\x05\x12\x16\n\x0e\x62uy_entrust_no\x18\t \x01(\x05\x12\x32\n\x0finstrument_type\x18\n \x01(\x0e\x32\x19.quote.tag.InstrumentType\"\xe5\x01\n\nOrdersData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\x13\n\x0bmillisecond\x18\x04 \x01(\x05\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x05\x12!\n\x04side\x18\x07 \x01(\x0e\x32\x13.quote.tag.SideType\x12\x12\n\nentrust_no\x18\x08 \x01(\x05\x12\x32\n\x0finstrument_type\x18\t \x01(\x0e\x32\x19.quote.tag.InstrumentType\"~\n\nOrdersNode\x12!\n\x04side\x18\x01 \x01(\x0e\x32\x13.quote.tag.SideType\x12\x14\n\x0c\x61\x63tual_count\x18\x02 \x01(\x05\x12\x14\n\x0corders_count\x18\x03 \x01(\x05\x12\r\n\x05price\x18\x04 \x01(\x01\x12\x12\n\norders_num\x18\x05 \x03(\x05\"\xe3\x01\n\x0fOrderQueuesData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\x13\n\x0bmillisecond\x18\x04 \x01(\x05\x12\x32\n\x0finstrument_type\x18\x05 \x01(\x0e\x32\x19.quote.tag.InstrumentType\x12%\n\nbuy_queues\x18\x06 \x01(\x0b\x32\x11.quote.OrdersNode\x12&\n\x0bsell_queues\x18\x07 \x01(\x0b\x32\x11.quote.OrdersNode\"\xfe\x02\n\x07\x42\x61rData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x0c\n\x04time\x18\x04 \x01(\t\x12\x0c\n\x04open\x18\x05 \x01(\x01\x12\x0c\n\x04high\x18\x06 \x01(\x01\x12\x0b\n\x03low\x18\x07 \x01(\x01\x12\r\n\x05\x63lose\x18\x08 \x01(\x01\x12\x0e\n\x06volume\x18\t \x01(\x05\x12\x15\n\ropen_interest\x18\n \x01(\x05\x12\x10\n\x08turnover\x18\x0b \x01(\x01\x12\x32\n\x0finstrument_type\x18\x0c \x01(\x0e\x32\x19.quote.tag.InstrumentType\x12\x15\n\rturnover_rate\x18\r \x01(\x01\x12\x11\n\tpre_close\x18\x0e \x01(\x01\x12\x0c\n\x04macd\x18\x0f \x01(\x01\x12\x0c\n\x04\x64iff\x18\x10 \x01(\x01\x12\x12\n\nlast_price\x18\x11 \x01(\x01\x12\x13\n\x0bprice_range\x18\x12 \x01(\x01\x12\x17\n\x0f\x64\x65\x66ined_formula\x18\x13 \x01(\x01\"\xc8\x02\n\nSharesData\x12\x13\n\x0bsecurity_id\x18\x01 \x01(\t\x12\x15\n\rsecurity_name\x18\x02 \x01(\t\x12\x19\n\x11upper_lower_range\x18\x03 \x01(\t\x12\x12\n\nlast_price\x18\x04 \x01(\t\x12\x15\n\rpurchase_date\x18\x05 \x01(\t\x12\x16\n\x0eon_market_date\x18\x06 \x01(\t\x12\x15\n\rinstrument_id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x14\n\x0csuccess_rate\x18\t \x01(\t\x12\x1a\n\x12upper_limit_volume\x18\n \x01(\t\x12\x19\n\x11one_highest_value\x18\x0b \x01(\x01\x12\x13\n\x0b\x65xchange_id\x18\x0c \x01(\t\x12\x11\n\tmarket_id\x18\r \x01(\t\x12\x15\n\ron_line_limit\x18\x0e \x01(\x05\"\x9f\x02\n\rBillboardData\x12\x13\n\x0bsecurity_id\x18\x01 \x01(\t\x12\x15\n\rsecurity_name\x18\x02 \x01(\t\x12\x19\n\x11upper_lower_range\x18\x03 \x01(\t\x12\x12\n\nlast_price\x18\x04 \x01(\t\x12\x11\n\tlist_date\x18\x05 \x01(\t\x12\x11\n\tnet_sales\x18\x06 \x01(\x01\x12\x14\n\x0clist_reasons\x18\x07 \x01(\t\x12\x11\n\tfrequency\x18\x08 \x01(\t\x12\x1a\n\x12total_market_value\x18\t \x01(\x01\x12 \n\x18\x63irculation_market_value\x18\n \x01(\x01\x12\x13\n\x0b\x65xchange_id\x18\x0b \x01(\t\x12\x11\n\tmarket_id\x18\x0c \x01(\t\"1\n\x10NotificationTick\x12\x1d\n\x04tick\x18\x01 \x01(\x0b\x32\x0f.quote.TickData\"I\n\x18NotificationTransactions\x12-\n\x0ctransactions\x18\x01 \x01(\x0b\x32\x17.quote.TransactionsData\";\n\x16NotificationOrdersData\x12!\n\x06orders\x18\x01 \x01(\x0b\x32\x11.quote.OrdersData\"J\n\x1bNotificationOrderQueuesData\x12+\n\x0bqueues_data\x18\x01 \x01(\x0b\x32\x16.quote.OrderQueuesData\"s\n\x11SubscribeQuoteReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"s\n\x11SubscribeQuoteRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"u\n\x13UnSubscribeQuoteReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"u\n\x13UnSubscribeQuoteRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"w\n\x15SubscribeTickQuoteReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"w\n\x15SubscribeTickQuoteRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"y\n\x17UnSubscribeTickQuoteReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"y\n\x17UnSubscribeTickQuoteRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"s\n\x11QueryLastQuoteReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x32\n\x0finstrument_type\x18\x03 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"2\n\x11QueryLastQuoteRsp\x12\x1d\n\x04tick\x18\x01 \x01(\x0b\x32\x0f.quote.TickData\"\xcb\x01\n\x0fQueryBarDataReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x32\n\x0finstrument_type\x18\x04 \x01(\x0e\x32\x19.quote.tag.InstrumentType\x12$\n\x08\x62\x61r_type\x18\x05 \x01(\x0e\x32\x12.quote.tag.BarType\x12\x12\n\nstart_time\x18\x06 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\t\"\xe0\x01\n\x0fQueryBarDataRsp\x12!\n\tbar_datas\x18\x01 \x03(\x0b\x32\x0e.quote.BarData\x12\x32\n\x0finstrument_type\x18\x02 \x01(\x0e\x32\x19.quote.tag.InstrumentType\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12\x15\n\rinstrument_id\x18\x04 \x01(\t\x12$\n\x08\x62\x61r_type\x18\x05 \x01(\x0e\x32\x12.quote.tag.BarType\x12\x12\n\nstart_time\x18\x06 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\t\"\x97\x01\n\x14QueryBatchBarDataReq\x12\x0f\n\x07symbols\x18\x01 \x01(\t\x12$\n\x08\x62\x61r_type\x18\x02 \x01(\x0e\x32\x12.quote.tag.BarType\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\x12\x0f\n\x07\x66ormula\x18\x06 \x01(\t\"\\\n\x0b\x42\x61rDataList\x12\x15\n\rinstrument_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12!\n\tbar_datas\x18\x03 \x03(\x0b\x32\x0e.quote.BarData\"\xc3\x01\n\x14QueryBatchBarDataRsp\x12\x0f\n\x07symbols\x18\x01 \x01(\t\x12$\n\x08\x62\x61r_type\x18\x02 \x01(\x0e\x32\x12.quote.tag.BarType\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12*\n\x0e\x62\x61r_datas_list\x18\x05 \x03(\x0b\x32\x12.quote.BarDataList\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12\x0f\n\x07\x66ormula\x18\x07 \x01(\t\"}\n\rDayBarDataReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x32\n\x0finstrument_type\x18\x04 \x01(\x0e\x32\x19.quote.tag.InstrumentType\"\xd7\x01\n\rDayBarDataRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x0c\n\x04open\x18\x04 \x01(\x01\x12\x0c\n\x04high\x18\x05 \x01(\x01\x12\x0b\n\x03low\x18\x06 \x01(\x01\x12\r\n\x05\x63lose\x18\x07 \x01(\x01\x12\x0e\n\x06volume\x18\x08 \x01(\x05\x12\x10\n\x08turnover\x18\t \x01(\x01\x12\x32\n\x0finstrument_type\x18\n \x01(\x0e\x32\x19.quote.tag.InstrumentType\"F\n\x1bQueryMaxActiveInstrumentReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\"]\n\x1bQueryMaxActiveInstrumentRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x15\n\rinstrument_id\x18\x03 \x01(\t\">\n\x16QuerySharesDataListReq\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\"`\n\x16QuerySharesDataListRsp\x12\"\n\x07history\x18\x01 \x03(\x0b\x32\x11.quote.SharesData\x12\"\n\x07\x66utures\x18\x02 \x03(\x0b\x32\x11.quote.SharesData\"%\n\x15QueryBillboardDataReq\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\";\n\x15QueryBillboardDataRsp\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.quote.BillboardData\"Q\n\x15QueryCapitalInflowReq\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\"\xf4\x01\n\x15QueryCapitalInflowRsp\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x19\n\x11main_force_inflow\x18\x04 \x01(\x01\x12\x1a\n\x12main_force_flowOut\x18\x05 \x01(\x01\x12\x1b\n\x13main_force_net_flow\x18\x06 \x01(\x01\x12#\n\x1bmain_force_net_flow_percent\x18\x07 \x01(\x01\x12\x14\n\x0ctotal_assets\x18\x08 \x01(\x01\x12\x12\n\nstock_name\x18\t \x01(\t\"\x95\x03\n\tQuoteData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x15\n\rchange_amount\x18\x03 \x01(\x01\x12\x13\n\x0b\x63hange_rate\x18\x04 \x01(\x01\x12\x11\n\tamplitude\x18\x05 \x01(\x01\x12\x12\n\nlast_price\x18\x06 \x01(\x01\x12\x0e\n\x06volume\x18\x07 \x01(\x01\x12\x10\n\x08turnover\x18\x08 \x01(\x01\x12\x12\n\nopen_price\x18\t \x01(\x01\x12\x17\n\x0fpre_close_price\x18\n \x01(\x01\x12\x15\n\rhighest_price\x18\x0b \x01(\x01\x12\x14\n\x0clowest_price\x18\x0c \x01(\x01\x12\x1f\n\x17\x66ive_minute_change_rate\x18\r \x01(\x01\x12\x14\n\x0cvolume_ratio\x18\x0e \x01(\x01\x12\x10\n\x08pe_ratio\x18\x0f \x01(\x01\x12\x15\n\rturnover_rate\x18\x10 \x01(\x01\x12\x14\n\x0clisting_date\x18\x11 \x01(\t\x12\x17\n\x0finstrument_name\x18\x12 \x01(\t\"p\n\x0fSectorStockData\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x11\n\tcode_name\x18\x03 \x01(\t\x12\x12\n\nlast_price\x18\x04 \x01(\x01\x12\x13\n\x0b\x63hange_rate\x18\x05 \x01(\x01\"/\n\x07NetData\x12\x0e\n\x06volume\x18\x01 \x01(\x01\x12\x14\n\x0cvolume_ratio\x18\x02 \x01(\x01\"\xe0\x04\n\nSectorData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x11\n\tsector_id\x18\x02 \x01(\t\x12\x13\n\x0b\x63hange_rate\x18\x03 \x01(\x01\x12\x1a\n\x12total_market_value\x18\x04 \x01(\x01\x12\x15\n\rturnover_rate\x18\x05 \x01(\x01\x12*\n\nrise_stock\x18\x06 \x01(\x0b\x32\x16.quote.SectorStockData\x12-\n\rdecline_stock\x18\x07 \x01(\x0b\x32\x16.quote.SectorStockData\x12\x12\n\nlast_price\x18\x08 \x01(\x01\x12\x15\n\rchange_amount\x18\t \x01(\x01\x12%\n\rmain_net_data\x18\n \x01(\x0b\x32\x0e.quote.NetData\x12*\n\x12super_big_net_data\x18\x0b \x01(\x0b\x32\x0e.quote.NetData\x12$\n\x0c\x62ig_net_data\x18\x0c \x01(\x0b\x32\x0e.quote.NetData\x12$\n\x0cmid_net_data\x18\r \x01(\x0b\x32\x0e.quote.NetData\x12%\n\rtiny_net_data\x18\x0e \x01(\x0b\x32\x0e.quote.NetData\x12\x1a\n\x12max_net_stock_code\x18\x0f \x01(\t\x12\x1a\n\x12max_net_stock_name\x18\x10 \x01(\t\x12!\n\x19max_net_stock_exchange_id\x18\x11 \x01(\t\x12\x13\n\x0bsector_name\x18\x12 \x01(\t\x12\x11\n\tup_counts\x18\x13 \x01(\x05\x12\x13\n\x0b\x64own_counts\x18\x14 \x01(\x05\"@\n\x17\x46iveMinutesQuoteDataRsp\x12%\n\x0bquote_datas\x18\x01 \x03(\x0b\x32\x10.quote.QuoteData\"]\n\x0cQuoteDataRsp\x12\x11\n\tsector_id\x18\x01 \x01(\t\x12%\n\x0bquote_datas\x18\x02 \x03(\x0b\x32\x10.quote.QuoteData\x12\x13\n\x0bsector_type\x18\x03 \x01(\x05\"`\n\rSectorDataRsp\x12\x11\n\tsector_id\x18\x01 \x01(\t\x12\'\n\x0csector_datas\x18\x02 \x03(\x0b\x32\x11.quote.SectorData\x12\x13\n\x0bsector_type\x18\x03 \x01(\x05\"\x87\x01\n\x13PositionChangesData\x12\x15\n\rinstrument_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x17\n\x0finstrument_name\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\"T\n\x16PositionChangesDataRsp\x12:\n\x16position_changes_datas\x18\x01 \x03(\x0b\x32\x1a.quote.PositionChangesData\"\"\n\x12QueryTradingDayReq\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\"8\n\x12QueryTradingDayRsp\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x12\n\ntradingday\x18\x02 \x01(\t\"]\n\x12QueryTickDetailReq\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\x12\x11\n\tdata_type\x18\x04 \x01(\t\"3\n\x12QueryTickDetailRsp\x12\x1d\n\x04tick\x18\x01 \x03(\x0b\x32\x0f.quote.TickDataB\x06\xa2\x02\x03QUTb\x06proto3')
  ,
  dependencies=[quote_dot_quote__enum__pb2.DESCRIPTOR,])




_BSNODE = _descriptor.Descriptor(
  name='BSNode',
  full_name='quote.BSNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='quote.BSNode.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.BSNode.volume', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=91,
)


_TICKDATA = _descriptor.Descriptor(
  name='TickData',
  full_name='quote.TickData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.TickData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.TickData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.TickData.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.TickData.time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='quote.TickData.millisecond', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.TickData.last_price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.TickData.volume', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_interest', full_name='quote.TickData.open_interest', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highest_price', full_name='quote.TickData.highest_price', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowest_price', full_name='quote.TickData.lowest_price', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_limit_price', full_name='quote.TickData.upper_limit_price', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_limit_price', full_name='quote.TickData.lower_limit_price', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_settlement_price', full_name='quote.TickData.pre_settlement_price', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_price', full_name='quote.TickData.average_price', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid', full_name='quote.TickData.bid', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ask', full_name='quote.TickData.ask', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='quote.TickData.open_price', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_close_price', full_name='quote.TickData.pre_close_price', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='quote.TickData.turnover', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.TickData.instrument_type', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_open_interest', full_name='quote.TickData.pre_open_interest', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_number', full_name='quote.TickData.trade_number', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_volume', full_name='quote.TickData.last_volume', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='up_down_in_five_min', full_name='quote.TickData.up_down_in_five_min', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspension_sign', full_name='quote.TickData.suspension_sign', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='quote.TickData.timestamp', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_code', full_name='quote.TickData.market_code', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_turnover', full_name='quote.TickData.last_turnover', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=766,
)


_TRANSACTIONSDATA = _descriptor.Descriptor(
  name='TransactionsData',
  full_name='quote.TransactionsData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.TransactionsData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.TransactionsData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.TransactionsData.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='quote.TransactionsData.millisecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='quote.TransactionsData.price', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.TransactionsData.volume', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='side', full_name='quote.TransactionsData.side', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sell_entrust_no', full_name='quote.TransactionsData.sell_entrust_no', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buy_entrust_no', full_name='quote.TransactionsData.buy_entrust_no', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.TransactionsData.instrument_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=1033,
)


_ORDERSDATA = _descriptor.Descriptor(
  name='OrdersData',
  full_name='quote.OrdersData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.OrdersData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.OrdersData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.OrdersData.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='quote.OrdersData.millisecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='quote.OrdersData.price', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.OrdersData.volume', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='side', full_name='quote.OrdersData.side', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entrust_no', full_name='quote.OrdersData.entrust_no', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.OrdersData.instrument_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1265,
)


_ORDERSNODE = _descriptor.Descriptor(
  name='OrdersNode',
  full_name='quote.OrdersNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='side', full_name='quote.OrdersNode.side', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actual_count', full_name='quote.OrdersNode.actual_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orders_count', full_name='quote.OrdersNode.orders_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='quote.OrdersNode.price', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orders_num', full_name='quote.OrdersNode.orders_num', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1393,
)


_ORDERQUEUESDATA = _descriptor.Descriptor(
  name='OrderQueuesData',
  full_name='quote.OrderQueuesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.OrderQueuesData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.OrderQueuesData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.OrderQueuesData.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='quote.OrderQueuesData.millisecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.OrderQueuesData.instrument_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buy_queues', full_name='quote.OrderQueuesData.buy_queues', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sell_queues', full_name='quote.OrderQueuesData.sell_queues', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1396,
  serialized_end=1623,
)


_BARDATA = _descriptor.Descriptor(
  name='BarData',
  full_name='quote.BarData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.BarData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.BarData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.BarData.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.BarData.time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='quote.BarData.open', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high', full_name='quote.BarData.high', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low', full_name='quote.BarData.low', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close', full_name='quote.BarData.close', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.BarData.volume', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_interest', full_name='quote.BarData.open_interest', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='quote.BarData.turnover', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.BarData.instrument_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover_rate', full_name='quote.BarData.turnover_rate', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_close', full_name='quote.BarData.pre_close', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macd', full_name='quote.BarData.macd', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diff', full_name='quote.BarData.diff', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.BarData.last_price', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_range', full_name='quote.BarData.price_range', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defined_formula', full_name='quote.BarData.defined_formula', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1626,
  serialized_end=2008,
)


_SHARESDATA = _descriptor.Descriptor(
  name='SharesData',
  full_name='quote.SharesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_id', full_name='quote.SharesData.security_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_name', full_name='quote.SharesData.security_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_lower_range', full_name='quote.SharesData.upper_lower_range', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.SharesData.last_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_date', full_name='quote.SharesData.purchase_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_market_date', full_name='quote.SharesData.on_market_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.SharesData.instrument_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='quote.SharesData.price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='quote.SharesData.success_rate', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_limit_volume', full_name='quote.SharesData.upper_limit_volume', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_highest_value', full_name='quote.SharesData.one_highest_value', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SharesData.exchange_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='quote.SharesData.market_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_line_limit', full_name='quote.SharesData.on_line_limit', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2339,
)


_BILLBOARDDATA = _descriptor.Descriptor(
  name='BillboardData',
  full_name='quote.BillboardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_id', full_name='quote.BillboardData.security_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_name', full_name='quote.BillboardData.security_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper_lower_range', full_name='quote.BillboardData.upper_lower_range', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.BillboardData.last_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_date', full_name='quote.BillboardData.list_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_sales', full_name='quote.BillboardData.net_sales', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_reasons', full_name='quote.BillboardData.list_reasons', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='quote.BillboardData.frequency', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_market_value', full_name='quote.BillboardData.total_market_value', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='circulation_market_value', full_name='quote.BillboardData.circulation_market_value', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.BillboardData.exchange_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='quote.BillboardData.market_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2629,
)


_NOTIFICATIONTICK = _descriptor.Descriptor(
  name='NotificationTick',
  full_name='quote.NotificationTick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick', full_name='quote.NotificationTick.tick', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2631,
  serialized_end=2680,
)


_NOTIFICATIONTRANSACTIONS = _descriptor.Descriptor(
  name='NotificationTransactions',
  full_name='quote.NotificationTransactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='quote.NotificationTransactions.transactions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2682,
  serialized_end=2755,
)


_NOTIFICATIONORDERSDATA = _descriptor.Descriptor(
  name='NotificationOrdersData',
  full_name='quote.NotificationOrdersData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='quote.NotificationOrdersData.orders', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2757,
  serialized_end=2816,
)


_NOTIFICATIONORDERQUEUESDATA = _descriptor.Descriptor(
  name='NotificationOrderQueuesData',
  full_name='quote.NotificationOrderQueuesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queues_data', full_name='quote.NotificationOrderQueuesData.queues_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2818,
  serialized_end=2892,
)


_SUBSCRIBEQUOTEREQ = _descriptor.Descriptor(
  name='SubscribeQuoteReq',
  full_name='quote.SubscribeQuoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SubscribeQuoteReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.SubscribeQuoteReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.SubscribeQuoteReq.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2894,
  serialized_end=3009,
)


_SUBSCRIBEQUOTERSP = _descriptor.Descriptor(
  name='SubscribeQuoteRsp',
  full_name='quote.SubscribeQuoteRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SubscribeQuoteRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.SubscribeQuoteRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.SubscribeQuoteRsp.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3011,
  serialized_end=3126,
)


_UNSUBSCRIBEQUOTEREQ = _descriptor.Descriptor(
  name='UnSubscribeQuoteReq',
  full_name='quote.UnSubscribeQuoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.UnSubscribeQuoteReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.UnSubscribeQuoteReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.UnSubscribeQuoteReq.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3128,
  serialized_end=3245,
)


_UNSUBSCRIBEQUOTERSP = _descriptor.Descriptor(
  name='UnSubscribeQuoteRsp',
  full_name='quote.UnSubscribeQuoteRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.UnSubscribeQuoteRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.UnSubscribeQuoteRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.UnSubscribeQuoteRsp.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3247,
  serialized_end=3364,
)


_SUBSCRIBETICKQUOTEREQ = _descriptor.Descriptor(
  name='SubscribeTickQuoteReq',
  full_name='quote.SubscribeTickQuoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SubscribeTickQuoteReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.SubscribeTickQuoteReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.SubscribeTickQuoteReq.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3366,
  serialized_end=3485,
)


_SUBSCRIBETICKQUOTERSP = _descriptor.Descriptor(
  name='SubscribeTickQuoteRsp',
  full_name='quote.SubscribeTickQuoteRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SubscribeTickQuoteRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.SubscribeTickQuoteRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.SubscribeTickQuoteRsp.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3487,
  serialized_end=3606,
)


_UNSUBSCRIBETICKQUOTEREQ = _descriptor.Descriptor(
  name='UnSubscribeTickQuoteReq',
  full_name='quote.UnSubscribeTickQuoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.UnSubscribeTickQuoteReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.UnSubscribeTickQuoteReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.UnSubscribeTickQuoteReq.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3729,
)


_UNSUBSCRIBETICKQUOTERSP = _descriptor.Descriptor(
  name='UnSubscribeTickQuoteRsp',
  full_name='quote.UnSubscribeTickQuoteRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.UnSubscribeTickQuoteRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.UnSubscribeTickQuoteRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.UnSubscribeTickQuoteRsp.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3731,
  serialized_end=3852,
)


_QUERYLASTQUOTEREQ = _descriptor.Descriptor(
  name='QueryLastQuoteReq',
  full_name='quote.QueryLastQuoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryLastQuoteReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryLastQuoteReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.QueryLastQuoteReq.instrument_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3854,
  serialized_end=3969,
)


_QUERYLASTQUOTERSP = _descriptor.Descriptor(
  name='QueryLastQuoteRsp',
  full_name='quote.QueryLastQuoteRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick', full_name='quote.QueryLastQuoteRsp.tick', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3971,
  serialized_end=4021,
)


_QUERYBARDATAREQ = _descriptor.Descriptor(
  name='QueryBarDataReq',
  full_name='quote.QueryBarDataReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryBarDataReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryBarDataReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.QueryBarDataReq.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.QueryBarDataReq.instrument_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_type', full_name='quote.QueryBarDataReq.bar_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='quote.QueryBarDataReq.start_time', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='quote.QueryBarDataReq.end_time', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4024,
  serialized_end=4227,
)


_QUERYBARDATARSP = _descriptor.Descriptor(
  name='QueryBarDataRsp',
  full_name='quote.QueryBarDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bar_datas', full_name='quote.QueryBarDataRsp.bar_datas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.QueryBarDataRsp.instrument_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryBarDataRsp.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryBarDataRsp.instrument_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_type', full_name='quote.QueryBarDataRsp.bar_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='quote.QueryBarDataRsp.start_time', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='quote.QueryBarDataRsp.end_time', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4230,
  serialized_end=4454,
)


_QUERYBATCHBARDATAREQ = _descriptor.Descriptor(
  name='QueryBatchBarDataReq',
  full_name='quote.QueryBatchBarDataReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='quote.QueryBatchBarDataReq.symbols', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_type', full_name='quote.QueryBatchBarDataReq.bar_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='quote.QueryBatchBarDataReq.start_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='quote.QueryBatchBarDataReq.end_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='quote.QueryBatchBarDataReq.data_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='quote.QueryBatchBarDataReq.formula', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4457,
  serialized_end=4608,
)


_BARDATALIST = _descriptor.Descriptor(
  name='BarDataList',
  full_name='quote.BarDataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.BarDataList.instrument_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.BarDataList.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_datas', full_name='quote.BarDataList.bar_datas', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4610,
  serialized_end=4702,
)


_QUERYBATCHBARDATARSP = _descriptor.Descriptor(
  name='QueryBatchBarDataRsp',
  full_name='quote.QueryBatchBarDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='quote.QueryBatchBarDataRsp.symbols', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_type', full_name='quote.QueryBatchBarDataRsp.bar_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='quote.QueryBatchBarDataRsp.start_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='quote.QueryBatchBarDataRsp.end_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_datas_list', full_name='quote.QueryBatchBarDataRsp.bar_datas_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='quote.QueryBatchBarDataRsp.data_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='quote.QueryBatchBarDataRsp.formula', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4705,
  serialized_end=4900,
)


_DAYBARDATAREQ = _descriptor.Descriptor(
  name='DayBarDataReq',
  full_name='quote.DayBarDataReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.DayBarDataReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.DayBarDataReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.DayBarDataReq.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.DayBarDataReq.instrument_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4902,
  serialized_end=5027,
)


_DAYBARDATARSP = _descriptor.Descriptor(
  name='DayBarDataRsp',
  full_name='quote.DayBarDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.DayBarDataRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.DayBarDataRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.DayBarDataRsp.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='quote.DayBarDataRsp.open', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high', full_name='quote.DayBarDataRsp.high', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low', full_name='quote.DayBarDataRsp.low', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close', full_name='quote.DayBarDataRsp.close', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.DayBarDataRsp.volume', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='quote.DayBarDataRsp.turnover', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_type', full_name='quote.DayBarDataRsp.instrument_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5030,
  serialized_end=5245,
)


_QUERYMAXACTIVEINSTRUMENTREQ = _descriptor.Descriptor(
  name='QueryMaxActiveInstrumentReq',
  full_name='quote.QueryMaxActiveInstrumentReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryMaxActiveInstrumentReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='quote.QueryMaxActiveInstrumentReq.product_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5247,
  serialized_end=5317,
)


_QUERYMAXACTIVEINSTRUMENTRSP = _descriptor.Descriptor(
  name='QueryMaxActiveInstrumentRsp',
  full_name='quote.QueryMaxActiveInstrumentRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryMaxActiveInstrumentRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='quote.QueryMaxActiveInstrumentRsp.product_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryMaxActiveInstrumentRsp.instrument_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5319,
  serialized_end=5412,
)


_QUERYSHARESDATALISTREQ = _descriptor.Descriptor(
  name='QuerySharesDataListReq',
  full_name='quote.QuerySharesDataListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_date', full_name='quote.QuerySharesDataListReq.start_date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='quote.QuerySharesDataListReq.end_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5414,
  serialized_end=5476,
)


_QUERYSHARESDATALISTRSP = _descriptor.Descriptor(
  name='QuerySharesDataListRsp',
  full_name='quote.QuerySharesDataListRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='history', full_name='quote.QuerySharesDataListRsp.history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='futures', full_name='quote.QuerySharesDataListRsp.futures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5478,
  serialized_end=5574,
)


_QUERYBILLBOARDDATAREQ = _descriptor.Descriptor(
  name='QueryBillboardDataReq',
  full_name='quote.QueryBillboardDataReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.QueryBillboardDataReq.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5576,
  serialized_end=5613,
)


_QUERYBILLBOARDDATARSP = _descriptor.Descriptor(
  name='QueryBillboardDataRsp',
  full_name='quote.QueryBillboardDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='quote.QueryBillboardDataRsp.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5615,
  serialized_end=5674,
)


_QUERYCAPITALINFLOWREQ = _descriptor.Descriptor(
  name='QueryCapitalInflowReq',
  full_name='quote.QueryCapitalInflowReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryCapitalInflowReq.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryCapitalInflowReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.QueryCapitalInflowReq.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5676,
  serialized_end=5757,
)


_QUERYCAPITALINFLOWRSP = _descriptor.Descriptor(
  name='QueryCapitalInflowRsp',
  full_name='quote.QueryCapitalInflowRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QueryCapitalInflowRsp.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QueryCapitalInflowRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.QueryCapitalInflowRsp.date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_force_inflow', full_name='quote.QueryCapitalInflowRsp.main_force_inflow', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_force_flowOut', full_name='quote.QueryCapitalInflowRsp.main_force_flowOut', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_force_net_flow', full_name='quote.QueryCapitalInflowRsp.main_force_net_flow', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_force_net_flow_percent', full_name='quote.QueryCapitalInflowRsp.main_force_net_flow_percent', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_assets', full_name='quote.QueryCapitalInflowRsp.total_assets', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stock_name', full_name='quote.QueryCapitalInflowRsp.stock_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5760,
  serialized_end=6004,
)


_QUOTEDATA = _descriptor.Descriptor(
  name='QuoteData',
  full_name='quote.QuoteData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.QuoteData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.QuoteData.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_amount', full_name='quote.QuoteData.change_amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_rate', full_name='quote.QuoteData.change_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='quote.QuoteData.amplitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.QuoteData.last_price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.QuoteData.volume', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover', full_name='quote.QuoteData.turnover', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='quote.QuoteData.open_price', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_close_price', full_name='quote.QuoteData.pre_close_price', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highest_price', full_name='quote.QuoteData.highest_price', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowest_price', full_name='quote.QuoteData.lowest_price', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='five_minute_change_rate', full_name='quote.QuoteData.five_minute_change_rate', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_ratio', full_name='quote.QuoteData.volume_ratio', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pe_ratio', full_name='quote.QuoteData.pe_ratio', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover_rate', full_name='quote.QuoteData.turnover_rate', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listing_date', full_name='quote.QuoteData.listing_date', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_name', full_name='quote.QuoteData.instrument_name', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6007,
  serialized_end=6412,
)


_SECTORSTOCKDATA = _descriptor.Descriptor(
  name='SectorStockData',
  full_name='quote.SectorStockData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='quote.SectorStockData.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SectorStockData.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code_name', full_name='quote.SectorStockData.code_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.SectorStockData.last_price', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_rate', full_name='quote.SectorStockData.change_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6414,
  serialized_end=6526,
)


_NETDATA = _descriptor.Descriptor(
  name='NetData',
  full_name='quote.NetData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume', full_name='quote.NetData.volume', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_ratio', full_name='quote.NetData.volume_ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6528,
  serialized_end=6575,
)


_SECTORDATA = _descriptor.Descriptor(
  name='SectorData',
  full_name='quote.SectorData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.SectorData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sector_id', full_name='quote.SectorData.sector_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_rate', full_name='quote.SectorData.change_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_market_value', full_name='quote.SectorData.total_market_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='turnover_rate', full_name='quote.SectorData.turnover_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rise_stock', full_name='quote.SectorData.rise_stock', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decline_stock', full_name='quote.SectorData.decline_stock', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='quote.SectorData.last_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_amount', full_name='quote.SectorData.change_amount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_net_data', full_name='quote.SectorData.main_net_data', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super_big_net_data', full_name='quote.SectorData.super_big_net_data', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='big_net_data', full_name='quote.SectorData.big_net_data', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid_net_data', full_name='quote.SectorData.mid_net_data', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiny_net_data', full_name='quote.SectorData.tiny_net_data', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_net_stock_code', full_name='quote.SectorData.max_net_stock_code', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_net_stock_name', full_name='quote.SectorData.max_net_stock_name', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_net_stock_exchange_id', full_name='quote.SectorData.max_net_stock_exchange_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sector_name', full_name='quote.SectorData.sector_name', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='up_counts', full_name='quote.SectorData.up_counts', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='down_counts', full_name='quote.SectorData.down_counts', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6578,
  serialized_end=7186,
)


_FIVEMINUTESQUOTEDATARSP = _descriptor.Descriptor(
  name='FiveMinutesQuoteDataRsp',
  full_name='quote.FiveMinutesQuoteDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quote_datas', full_name='quote.FiveMinutesQuoteDataRsp.quote_datas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7188,
  serialized_end=7252,
)


_QUOTEDATARSP = _descriptor.Descriptor(
  name='QuoteDataRsp',
  full_name='quote.QuoteDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sector_id', full_name='quote.QuoteDataRsp.sector_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quote_datas', full_name='quote.QuoteDataRsp.quote_datas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sector_type', full_name='quote.QuoteDataRsp.sector_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7254,
  serialized_end=7347,
)


_SECTORDATARSP = _descriptor.Descriptor(
  name='SectorDataRsp',
  full_name='quote.SectorDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sector_id', full_name='quote.SectorDataRsp.sector_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sector_datas', full_name='quote.SectorDataRsp.sector_datas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sector_type', full_name='quote.SectorDataRsp.sector_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7349,
  serialized_end=7445,
)


_POSITIONCHANGESDATA = _descriptor.Descriptor(
  name='PositionChangesData',
  full_name='quote.PositionChangesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='quote.PositionChangesData.instrument_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='quote.PositionChangesData.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='quote.PositionChangesData.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='quote.PositionChangesData.content', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_name', full_name='quote.PositionChangesData.instrument_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='quote.PositionChangesData.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7448,
  serialized_end=7583,
)


_POSITIONCHANGESDATARSP = _descriptor.Descriptor(
  name='PositionChangesDataRsp',
  full_name='quote.PositionChangesDataRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position_changes_datas', full_name='quote.PositionChangesDataRsp.position_changes_datas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7585,
  serialized_end=7669,
)


_QUERYTRADINGDAYREQ = _descriptor.Descriptor(
  name='QueryTradingDayReq',
  full_name='quote.QueryTradingDayReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='quote.QueryTradingDayReq.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7671,
  serialized_end=7705,
)


_QUERYTRADINGDAYRSP = _descriptor.Descriptor(
  name='QueryTradingDayRsp',
  full_name='quote.QueryTradingDayRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='quote.QueryTradingDayRsp.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tradingday', full_name='quote.QueryTradingDayRsp.tradingday', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7707,
  serialized_end=7763,
)


_QUERYTICKDETAILREQ = _descriptor.Descriptor(
  name='QueryTickDetailReq',
  full_name='quote.QueryTickDetailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='quote.QueryTickDetailReq.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='quote.QueryTickDetailReq.start_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='quote.QueryTickDetailReq.end_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='quote.QueryTickDetailReq.data_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7765,
  serialized_end=7858,
)


_QUERYTICKDETAILRSP = _descriptor.Descriptor(
  name='QueryTickDetailRsp',
  full_name='quote.QueryTickDetailRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick', full_name='quote.QueryTickDetailRsp.tick', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7860,
  serialized_end=7911,
)

_TICKDATA.fields_by_name['bid'].message_type = _BSNODE
_TICKDATA.fields_by_name['ask'].message_type = _BSNODE
_TICKDATA.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_TRANSACTIONSDATA.fields_by_name['side'].enum_type = quote_dot_quote__enum__pb2._SIDETYPE
_TRANSACTIONSDATA.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_ORDERSDATA.fields_by_name['side'].enum_type = quote_dot_quote__enum__pb2._SIDETYPE
_ORDERSDATA.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_ORDERSNODE.fields_by_name['side'].enum_type = quote_dot_quote__enum__pb2._SIDETYPE
_ORDERQUEUESDATA.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_ORDERQUEUESDATA.fields_by_name['buy_queues'].message_type = _ORDERSNODE
_ORDERQUEUESDATA.fields_by_name['sell_queues'].message_type = _ORDERSNODE
_BARDATA.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_NOTIFICATIONTICK.fields_by_name['tick'].message_type = _TICKDATA
_NOTIFICATIONTRANSACTIONS.fields_by_name['transactions'].message_type = _TRANSACTIONSDATA
_NOTIFICATIONORDERSDATA.fields_by_name['orders'].message_type = _ORDERSDATA
_NOTIFICATIONORDERQUEUESDATA.fields_by_name['queues_data'].message_type = _ORDERQUEUESDATA
_SUBSCRIBEQUOTEREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_SUBSCRIBEQUOTERSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_UNSUBSCRIBEQUOTEREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_UNSUBSCRIBEQUOTERSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_SUBSCRIBETICKQUOTEREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_SUBSCRIBETICKQUOTERSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_UNSUBSCRIBETICKQUOTEREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_UNSUBSCRIBETICKQUOTERSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_QUERYLASTQUOTEREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_QUERYLASTQUOTERSP.fields_by_name['tick'].message_type = _TICKDATA
_QUERYBARDATAREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_QUERYBARDATAREQ.fields_by_name['bar_type'].enum_type = quote_dot_quote__enum__pb2._BARTYPE
_QUERYBARDATARSP.fields_by_name['bar_datas'].message_type = _BARDATA
_QUERYBARDATARSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_QUERYBARDATARSP.fields_by_name['bar_type'].enum_type = quote_dot_quote__enum__pb2._BARTYPE
_QUERYBATCHBARDATAREQ.fields_by_name['bar_type'].enum_type = quote_dot_quote__enum__pb2._BARTYPE
_BARDATALIST.fields_by_name['bar_datas'].message_type = _BARDATA
_QUERYBATCHBARDATARSP.fields_by_name['bar_type'].enum_type = quote_dot_quote__enum__pb2._BARTYPE
_QUERYBATCHBARDATARSP.fields_by_name['bar_datas_list'].message_type = _BARDATALIST
_DAYBARDATAREQ.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_DAYBARDATARSP.fields_by_name['instrument_type'].enum_type = quote_dot_quote__enum__pb2._INSTRUMENTTYPE
_QUERYSHARESDATALISTRSP.fields_by_name['history'].message_type = _SHARESDATA
_QUERYSHARESDATALISTRSP.fields_by_name['futures'].message_type = _SHARESDATA
_QUERYBILLBOARDDATARSP.fields_by_name['data'].message_type = _BILLBOARDDATA
_SECTORDATA.fields_by_name['rise_stock'].message_type = _SECTORSTOCKDATA
_SECTORDATA.fields_by_name['decline_stock'].message_type = _SECTORSTOCKDATA
_SECTORDATA.fields_by_name['main_net_data'].message_type = _NETDATA
_SECTORDATA.fields_by_name['super_big_net_data'].message_type = _NETDATA
_SECTORDATA.fields_by_name['big_net_data'].message_type = _NETDATA
_SECTORDATA.fields_by_name['mid_net_data'].message_type = _NETDATA
_SECTORDATA.fields_by_name['tiny_net_data'].message_type = _NETDATA
_FIVEMINUTESQUOTEDATARSP.fields_by_name['quote_datas'].message_type = _QUOTEDATA
_QUOTEDATARSP.fields_by_name['quote_datas'].message_type = _QUOTEDATA
_SECTORDATARSP.fields_by_name['sector_datas'].message_type = _SECTORDATA
_POSITIONCHANGESDATARSP.fields_by_name['position_changes_datas'].message_type = _POSITIONCHANGESDATA
_QUERYTICKDETAILRSP.fields_by_name['tick'].message_type = _TICKDATA
DESCRIPTOR.message_types_by_name['BSNode'] = _BSNODE
DESCRIPTOR.message_types_by_name['TickData'] = _TICKDATA
DESCRIPTOR.message_types_by_name['TransactionsData'] = _TRANSACTIONSDATA
DESCRIPTOR.message_types_by_name['OrdersData'] = _ORDERSDATA
DESCRIPTOR.message_types_by_name['OrdersNode'] = _ORDERSNODE
DESCRIPTOR.message_types_by_name['OrderQueuesData'] = _ORDERQUEUESDATA
DESCRIPTOR.message_types_by_name['BarData'] = _BARDATA
DESCRIPTOR.message_types_by_name['SharesData'] = _SHARESDATA
DESCRIPTOR.message_types_by_name['BillboardData'] = _BILLBOARDDATA
DESCRIPTOR.message_types_by_name['NotificationTick'] = _NOTIFICATIONTICK
DESCRIPTOR.message_types_by_name['NotificationTransactions'] = _NOTIFICATIONTRANSACTIONS
DESCRIPTOR.message_types_by_name['NotificationOrdersData'] = _NOTIFICATIONORDERSDATA
DESCRIPTOR.message_types_by_name['NotificationOrderQueuesData'] = _NOTIFICATIONORDERQUEUESDATA
DESCRIPTOR.message_types_by_name['SubscribeQuoteReq'] = _SUBSCRIBEQUOTEREQ
DESCRIPTOR.message_types_by_name['SubscribeQuoteRsp'] = _SUBSCRIBEQUOTERSP
DESCRIPTOR.message_types_by_name['UnSubscribeQuoteReq'] = _UNSUBSCRIBEQUOTEREQ
DESCRIPTOR.message_types_by_name['UnSubscribeQuoteRsp'] = _UNSUBSCRIBEQUOTERSP
DESCRIPTOR.message_types_by_name['SubscribeTickQuoteReq'] = _SUBSCRIBETICKQUOTEREQ
DESCRIPTOR.message_types_by_name['SubscribeTickQuoteRsp'] = _SUBSCRIBETICKQUOTERSP
DESCRIPTOR.message_types_by_name['UnSubscribeTickQuoteReq'] = _UNSUBSCRIBETICKQUOTEREQ
DESCRIPTOR.message_types_by_name['UnSubscribeTickQuoteRsp'] = _UNSUBSCRIBETICKQUOTERSP
DESCRIPTOR.message_types_by_name['QueryLastQuoteReq'] = _QUERYLASTQUOTEREQ
DESCRIPTOR.message_types_by_name['QueryLastQuoteRsp'] = _QUERYLASTQUOTERSP
DESCRIPTOR.message_types_by_name['QueryBarDataReq'] = _QUERYBARDATAREQ
DESCRIPTOR.message_types_by_name['QueryBarDataRsp'] = _QUERYBARDATARSP
DESCRIPTOR.message_types_by_name['QueryBatchBarDataReq'] = _QUERYBATCHBARDATAREQ
DESCRIPTOR.message_types_by_name['BarDataList'] = _BARDATALIST
DESCRIPTOR.message_types_by_name['QueryBatchBarDataRsp'] = _QUERYBATCHBARDATARSP
DESCRIPTOR.message_types_by_name['DayBarDataReq'] = _DAYBARDATAREQ
DESCRIPTOR.message_types_by_name['DayBarDataRsp'] = _DAYBARDATARSP
DESCRIPTOR.message_types_by_name['QueryMaxActiveInstrumentReq'] = _QUERYMAXACTIVEINSTRUMENTREQ
DESCRIPTOR.message_types_by_name['QueryMaxActiveInstrumentRsp'] = _QUERYMAXACTIVEINSTRUMENTRSP
DESCRIPTOR.message_types_by_name['QuerySharesDataListReq'] = _QUERYSHARESDATALISTREQ
DESCRIPTOR.message_types_by_name['QuerySharesDataListRsp'] = _QUERYSHARESDATALISTRSP
DESCRIPTOR.message_types_by_name['QueryBillboardDataReq'] = _QUERYBILLBOARDDATAREQ
DESCRIPTOR.message_types_by_name['QueryBillboardDataRsp'] = _QUERYBILLBOARDDATARSP
DESCRIPTOR.message_types_by_name['QueryCapitalInflowReq'] = _QUERYCAPITALINFLOWREQ
DESCRIPTOR.message_types_by_name['QueryCapitalInflowRsp'] = _QUERYCAPITALINFLOWRSP
DESCRIPTOR.message_types_by_name['QuoteData'] = _QUOTEDATA
DESCRIPTOR.message_types_by_name['SectorStockData'] = _SECTORSTOCKDATA
DESCRIPTOR.message_types_by_name['NetData'] = _NETDATA
DESCRIPTOR.message_types_by_name['SectorData'] = _SECTORDATA
DESCRIPTOR.message_types_by_name['FiveMinutesQuoteDataRsp'] = _FIVEMINUTESQUOTEDATARSP
DESCRIPTOR.message_types_by_name['QuoteDataRsp'] = _QUOTEDATARSP
DESCRIPTOR.message_types_by_name['SectorDataRsp'] = _SECTORDATARSP
DESCRIPTOR.message_types_by_name['PositionChangesData'] = _POSITIONCHANGESDATA
DESCRIPTOR.message_types_by_name['PositionChangesDataRsp'] = _POSITIONCHANGESDATARSP
DESCRIPTOR.message_types_by_name['QueryTradingDayReq'] = _QUERYTRADINGDAYREQ
DESCRIPTOR.message_types_by_name['QueryTradingDayRsp'] = _QUERYTRADINGDAYRSP
DESCRIPTOR.message_types_by_name['QueryTickDetailReq'] = _QUERYTICKDETAILREQ
DESCRIPTOR.message_types_by_name['QueryTickDetailRsp'] = _QUERYTICKDETAILRSP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BSNode = _reflection.GeneratedProtocolMessageType('BSNode', (_message.Message,), {
  'DESCRIPTOR' : _BSNODE,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.BSNode)
  })
_sym_db.RegisterMessage(BSNode)

TickData = _reflection.GeneratedProtocolMessageType('TickData', (_message.Message,), {
  'DESCRIPTOR' : _TICKDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.TickData)
  })
_sym_db.RegisterMessage(TickData)

TransactionsData = _reflection.GeneratedProtocolMessageType('TransactionsData', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.TransactionsData)
  })
_sym_db.RegisterMessage(TransactionsData)

OrdersData = _reflection.GeneratedProtocolMessageType('OrdersData', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.OrdersData)
  })
_sym_db.RegisterMessage(OrdersData)

OrdersNode = _reflection.GeneratedProtocolMessageType('OrdersNode', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSNODE,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.OrdersNode)
  })
_sym_db.RegisterMessage(OrdersNode)

OrderQueuesData = _reflection.GeneratedProtocolMessageType('OrderQueuesData', (_message.Message,), {
  'DESCRIPTOR' : _ORDERQUEUESDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.OrderQueuesData)
  })
_sym_db.RegisterMessage(OrderQueuesData)

BarData = _reflection.GeneratedProtocolMessageType('BarData', (_message.Message,), {
  'DESCRIPTOR' : _BARDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.BarData)
  })
_sym_db.RegisterMessage(BarData)

SharesData = _reflection.GeneratedProtocolMessageType('SharesData', (_message.Message,), {
  'DESCRIPTOR' : _SHARESDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SharesData)
  })
_sym_db.RegisterMessage(SharesData)

BillboardData = _reflection.GeneratedProtocolMessageType('BillboardData', (_message.Message,), {
  'DESCRIPTOR' : _BILLBOARDDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.BillboardData)
  })
_sym_db.RegisterMessage(BillboardData)

NotificationTick = _reflection.GeneratedProtocolMessageType('NotificationTick', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONTICK,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.NotificationTick)
  })
_sym_db.RegisterMessage(NotificationTick)

NotificationTransactions = _reflection.GeneratedProtocolMessageType('NotificationTransactions', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONTRANSACTIONS,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.NotificationTransactions)
  })
_sym_db.RegisterMessage(NotificationTransactions)

NotificationOrdersData = _reflection.GeneratedProtocolMessageType('NotificationOrdersData', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONORDERSDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.NotificationOrdersData)
  })
_sym_db.RegisterMessage(NotificationOrdersData)

NotificationOrderQueuesData = _reflection.GeneratedProtocolMessageType('NotificationOrderQueuesData', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONORDERQUEUESDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.NotificationOrderQueuesData)
  })
_sym_db.RegisterMessage(NotificationOrderQueuesData)

SubscribeQuoteReq = _reflection.GeneratedProtocolMessageType('SubscribeQuoteReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEQUOTEREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SubscribeQuoteReq)
  })
_sym_db.RegisterMessage(SubscribeQuoteReq)

SubscribeQuoteRsp = _reflection.GeneratedProtocolMessageType('SubscribeQuoteRsp', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEQUOTERSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SubscribeQuoteRsp)
  })
_sym_db.RegisterMessage(SubscribeQuoteRsp)

UnSubscribeQuoteReq = _reflection.GeneratedProtocolMessageType('UnSubscribeQuoteReq', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBEQUOTEREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.UnSubscribeQuoteReq)
  })
_sym_db.RegisterMessage(UnSubscribeQuoteReq)

UnSubscribeQuoteRsp = _reflection.GeneratedProtocolMessageType('UnSubscribeQuoteRsp', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBEQUOTERSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.UnSubscribeQuoteRsp)
  })
_sym_db.RegisterMessage(UnSubscribeQuoteRsp)

SubscribeTickQuoteReq = _reflection.GeneratedProtocolMessageType('SubscribeTickQuoteReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETICKQUOTEREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SubscribeTickQuoteReq)
  })
_sym_db.RegisterMessage(SubscribeTickQuoteReq)

SubscribeTickQuoteRsp = _reflection.GeneratedProtocolMessageType('SubscribeTickQuoteRsp', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETICKQUOTERSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SubscribeTickQuoteRsp)
  })
_sym_db.RegisterMessage(SubscribeTickQuoteRsp)

UnSubscribeTickQuoteReq = _reflection.GeneratedProtocolMessageType('UnSubscribeTickQuoteReq', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBETICKQUOTEREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.UnSubscribeTickQuoteReq)
  })
_sym_db.RegisterMessage(UnSubscribeTickQuoteReq)

UnSubscribeTickQuoteRsp = _reflection.GeneratedProtocolMessageType('UnSubscribeTickQuoteRsp', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBETICKQUOTERSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.UnSubscribeTickQuoteRsp)
  })
_sym_db.RegisterMessage(UnSubscribeTickQuoteRsp)

QueryLastQuoteReq = _reflection.GeneratedProtocolMessageType('QueryLastQuoteReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTQUOTEREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryLastQuoteReq)
  })
_sym_db.RegisterMessage(QueryLastQuoteReq)

QueryLastQuoteRsp = _reflection.GeneratedProtocolMessageType('QueryLastQuoteRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTQUOTERSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryLastQuoteRsp)
  })
_sym_db.RegisterMessage(QueryLastQuoteRsp)

QueryBarDataReq = _reflection.GeneratedProtocolMessageType('QueryBarDataReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBARDATAREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBarDataReq)
  })
_sym_db.RegisterMessage(QueryBarDataReq)

QueryBarDataRsp = _reflection.GeneratedProtocolMessageType('QueryBarDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBARDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBarDataRsp)
  })
_sym_db.RegisterMessage(QueryBarDataRsp)

QueryBatchBarDataReq = _reflection.GeneratedProtocolMessageType('QueryBatchBarDataReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHBARDATAREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBatchBarDataReq)
  })
_sym_db.RegisterMessage(QueryBatchBarDataReq)

BarDataList = _reflection.GeneratedProtocolMessageType('BarDataList', (_message.Message,), {
  'DESCRIPTOR' : _BARDATALIST,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.BarDataList)
  })
_sym_db.RegisterMessage(BarDataList)

QueryBatchBarDataRsp = _reflection.GeneratedProtocolMessageType('QueryBatchBarDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHBARDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBatchBarDataRsp)
  })
_sym_db.RegisterMessage(QueryBatchBarDataRsp)

DayBarDataReq = _reflection.GeneratedProtocolMessageType('DayBarDataReq', (_message.Message,), {
  'DESCRIPTOR' : _DAYBARDATAREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.DayBarDataReq)
  })
_sym_db.RegisterMessage(DayBarDataReq)

DayBarDataRsp = _reflection.GeneratedProtocolMessageType('DayBarDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _DAYBARDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.DayBarDataRsp)
  })
_sym_db.RegisterMessage(DayBarDataRsp)

QueryMaxActiveInstrumentReq = _reflection.GeneratedProtocolMessageType('QueryMaxActiveInstrumentReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMAXACTIVEINSTRUMENTREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryMaxActiveInstrumentReq)
  })
_sym_db.RegisterMessage(QueryMaxActiveInstrumentReq)

QueryMaxActiveInstrumentRsp = _reflection.GeneratedProtocolMessageType('QueryMaxActiveInstrumentRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMAXACTIVEINSTRUMENTRSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryMaxActiveInstrumentRsp)
  })
_sym_db.RegisterMessage(QueryMaxActiveInstrumentRsp)

QuerySharesDataListReq = _reflection.GeneratedProtocolMessageType('QuerySharesDataListReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSHARESDATALISTREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QuerySharesDataListReq)
  })
_sym_db.RegisterMessage(QuerySharesDataListReq)

QuerySharesDataListRsp = _reflection.GeneratedProtocolMessageType('QuerySharesDataListRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSHARESDATALISTRSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QuerySharesDataListRsp)
  })
_sym_db.RegisterMessage(QuerySharesDataListRsp)

QueryBillboardDataReq = _reflection.GeneratedProtocolMessageType('QueryBillboardDataReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBILLBOARDDATAREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBillboardDataReq)
  })
_sym_db.RegisterMessage(QueryBillboardDataReq)

QueryBillboardDataRsp = _reflection.GeneratedProtocolMessageType('QueryBillboardDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBILLBOARDDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryBillboardDataRsp)
  })
_sym_db.RegisterMessage(QueryBillboardDataRsp)

QueryCapitalInflowReq = _reflection.GeneratedProtocolMessageType('QueryCapitalInflowReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCAPITALINFLOWREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryCapitalInflowReq)
  })
_sym_db.RegisterMessage(QueryCapitalInflowReq)

QueryCapitalInflowRsp = _reflection.GeneratedProtocolMessageType('QueryCapitalInflowRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCAPITALINFLOWRSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryCapitalInflowRsp)
  })
_sym_db.RegisterMessage(QueryCapitalInflowRsp)

QuoteData = _reflection.GeneratedProtocolMessageType('QuoteData', (_message.Message,), {
  'DESCRIPTOR' : _QUOTEDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QuoteData)
  })
_sym_db.RegisterMessage(QuoteData)

SectorStockData = _reflection.GeneratedProtocolMessageType('SectorStockData', (_message.Message,), {
  'DESCRIPTOR' : _SECTORSTOCKDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SectorStockData)
  })
_sym_db.RegisterMessage(SectorStockData)

NetData = _reflection.GeneratedProtocolMessageType('NetData', (_message.Message,), {
  'DESCRIPTOR' : _NETDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.NetData)
  })
_sym_db.RegisterMessage(NetData)

SectorData = _reflection.GeneratedProtocolMessageType('SectorData', (_message.Message,), {
  'DESCRIPTOR' : _SECTORDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SectorData)
  })
_sym_db.RegisterMessage(SectorData)

FiveMinutesQuoteDataRsp = _reflection.GeneratedProtocolMessageType('FiveMinutesQuoteDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _FIVEMINUTESQUOTEDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.FiveMinutesQuoteDataRsp)
  })
_sym_db.RegisterMessage(FiveMinutesQuoteDataRsp)

QuoteDataRsp = _reflection.GeneratedProtocolMessageType('QuoteDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUOTEDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QuoteDataRsp)
  })
_sym_db.RegisterMessage(QuoteDataRsp)

SectorDataRsp = _reflection.GeneratedProtocolMessageType('SectorDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _SECTORDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.SectorDataRsp)
  })
_sym_db.RegisterMessage(SectorDataRsp)

PositionChangesData = _reflection.GeneratedProtocolMessageType('PositionChangesData', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONCHANGESDATA,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.PositionChangesData)
  })
_sym_db.RegisterMessage(PositionChangesData)

PositionChangesDataRsp = _reflection.GeneratedProtocolMessageType('PositionChangesDataRsp', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONCHANGESDATARSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.PositionChangesDataRsp)
  })
_sym_db.RegisterMessage(PositionChangesDataRsp)

QueryTradingDayReq = _reflection.GeneratedProtocolMessageType('QueryTradingDayReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADINGDAYREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryTradingDayReq)
  })
_sym_db.RegisterMessage(QueryTradingDayReq)

QueryTradingDayRsp = _reflection.GeneratedProtocolMessageType('QueryTradingDayRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADINGDAYRSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryTradingDayRsp)
  })
_sym_db.RegisterMessage(QueryTradingDayRsp)

QueryTickDetailReq = _reflection.GeneratedProtocolMessageType('QueryTickDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTICKDETAILREQ,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryTickDetailReq)
  })
_sym_db.RegisterMessage(QueryTickDetailReq)

QueryTickDetailRsp = _reflection.GeneratedProtocolMessageType('QueryTickDetailRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTICKDETAILRSP,
  '__module__' : 'quote.quote_pb2'
  # @@protoc_insertion_point(class_scope:quote.QueryTickDetailRsp)
  })
_sym_db.RegisterMessage(QueryTickDetailRsp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
